[Sciviews-commits] r423 - pkg/svDialogs/R

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Tue Jan 31 12:05:11 CET 2012


Author: phgrosjean
Date: 2012-01-31 12:05:11 +0100 (Tue, 31 Jan 2012)
New Revision: 423

Modified:
   pkg/svDialogs/R/menu.R
Log:
Default R menu can be set by the option RMenuFile in svDialogs

Modified: pkg/svDialogs/R/menu.R
===================================================================
--- pkg/svDialogs/R/menu.R	2012-01-31 10:57:56 UTC (rev 422)
+++ pkg/svDialogs/R/menu.R	2012-01-31 11:05:11 UTC (rev 423)
@@ -183,9 +183,9 @@
 ## sudo apt-get install xvkbd xdotool
 ## Warning, you need to insqtall the English (US) keymap, even if you don't use
 ## it. Otherwise, xvkbd will issue strange things in your R console!
 ## TODO: install and configure myGTKmenu... + add shortcut keys!
 ## Use xbindkeys to bind shell commands to keyboard and mouse keys
-## chmod +x myGtkmenu
+## chmod +x ctxmenu
 ##
 ## THIS IS THE OLD VERSION (COMMENTED CODE BELLOW!)
 ## Explanation: to run this, you need to install xvkbd and file-browser-applet
@@ -220,7 +220,8 @@
 	## Initialize the R menu file with default items
 	fil <- .unixMenuFile()
 	## Get the default R menu and start from there
-	def <- file.path("~", "SciViews", "menus", "RMenu.txt")
+	def <- getOption("RMenuFile",
+		default = file.path("~", ".ctxmenu", "RMenu.txt"))
 	if (file.exists(def)) {
 		file.copy(def, fil, overwrite = TRUE)
 	} else file.copy(system.file("gui", "RMenu.txt", package = "svDialogs"),
@@ -183,9 +183,9 @@
 ## Warning, you need to insqtall the English (US) keymap, even if you don't use
 ## it. Otherwise, xvkbd will issue strange things in your R console!
-## TODO: install and configure myGTKmenu... + add shortcut keys!
+## TODO: install and configure ctxmenu... + add shortcut keys!
 ## Use xbindkeys to bind shell commands to keyboard and mouse keys



More information about the Sciviews-commits mailing list